==> react-amplify-wrapper-1.0.1.tgz: package/dispatches.ts <==
import { 
    signUpAction, signInAction, confirmSignUpAction, resendConfirmationCodeAction,
    signOutAction, forgotPasswordAction, forgotNewPasswordSubmitAction, changePasswordAction,
    changeAttributesAction
} from './actions/creators'
 
export default function authDispatches(dispatch: any) {

    return {
        signUp: (user: {
            email: string, 
            password: string, 
            firstName: string, 
            lastName: string,
        }): void => dispatch(
            signUpAction({...user})
        ),

        confirmSignUp: (
            confirmationCode: string,
        ): void => dispatch(
            confirmSignUpAction(confirmationCode)
        ),

        resendConfirmationCode: (
            email: string,
        ): void => dispatch(
            resendConfirmationCodeAction(email)
        ),

        signIn: (
            email: string, 
            password: string,
        ): void => dispatch(
            signInAction(email, password)
        ),

        signOut: (): void => dispatch(signOutAction()),

        forgotPassword: (email: string): void => dispatch(forgotPasswordAction(email)),
        
        forgotPasswordSubmit: (
            code: string, 
            newPassword: string,
        ): void => dispatch(forgotNewPasswordSubmitAction(code, newPassword)),

        changePassword: (
            oldPassword: string, 
            newPassword: string,
        ): void => dispatch(changePasswordAction(oldPassword, newPassword)),

        changeAttributes: (
            name: string, 
            email: string,
        ): void => dispatch(changeAttributesAction(name, email)),
    }
}

==> react-amplify-wrapper-1.0.8.tgz: package/dispatches.ts <==
import { 
    signUpAction, signInAction, confirmSignUpAction, resendConfirmationCodeAction,
    signOutAction, forgotPasswordAction, forgotPasswordSubmitAction, changePasswordAction,
    changeAttributesAction
} from './actions/creators'
 
export default function authDispatches(dispatch: any) {

    return {
        signUp: (user: {
            email: string, 
            password: string, 
            firstName: string, 
            lastName: string,
        }): void => dispatch(
            signUpAction({...user})
        ),

        confirmSignUp: (
            confirmationCode: string,
        ): void => dispatch(
            confirmSignUpAction(confirmationCode)
        ),

        resendConfirmationCode: (
            email: string,
        ): void => dispatch(
            resendConfirmationCodeAction(email)
        ),

        signIn: (
            email: string, 
            password: string,
        ): void => dispatch(
            signInAction(email, password)
        ),

        signOut: (): void => dispatch(signOutAction()),

        forgotPassword: (email: string): void => dispatch(forgotPasswordAction(email)),
        
        forgotPasswordSubmit: (
            code: string, 
            newPassword: string,
        ): void => dispatch(forgotPasswordSubmitAction(code, newPassword)),

        changePassword: (
            oldPassword: string, 
            newPassword: string,
        ): void => dispatch(changePasswordAction(oldPassword, newPassword)),

        changeAttributes: (
            name: string, 
            email: string,
        ): void => dispatch(changeAttributesAction(name, email)),
    }
}
